<!-- Auto generate API references with mkdocstrings https://mkdocstrings.github.io/usage/#usage -->

::: kubernetes_lite

::: kubernetes_lite.client

::: kubernetes_lite.envtest

::: kubernetes_lite.setup_envtest
